==> wikitty-api-3.10-sources.jar: org/nuiton/wikitty/services/WikittyExtensionMigrationRegistry.java <==
/*
 * #%L
 * Wikitty :: api
 * 
 * $Id: WikittyExtensionMigrationRegistry.java 1462 2012-04-05 15:31:15Z maven-release $
 * $HeadURL: http://svn.nuiton.org/svn/wikitty/tags/wikitty-3.10/wikitty-api/src/main/java/org/nuiton/wikitty/services/WikittyExtensionMigrationRegistry.java $
 * %%
 * Copyright (C) 2012 CodeLutin, Benjamin Poussin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */
package org.nuiton.wikitty.services;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.nuiton.util.ApplicationConfig;
import org.nuiton.wikitty.WikittyConfigOption;
import org.nuiton.wikitty.WikittyException;

/**
 * Permet de gerer les objets permettant les migrations d'extension. Il est
 * possible d'ajouter programmatiquement des objects de migration ou bien en
 * utilisant la configuration. Si les deux sont utilises l'ajout par programmation
 * est toujours preponderant sur l'utilisation du fichier de configuration.
 *
 * Pour recuperer l'objet WikittyExtensionMigrationRegistry il faut utiliser
 * <pre>
 * ApplicationConfig config = ...;
 * WikittyExtensionMigrationRegistry registry =
 *     config.getObject(WikittyExtensionMigrationRegistry.class);
 * WikittyExtensionMigration migration = registry.get(WikittyUser.EXT_WIKITTYUSER);
 * </pre>
 *
 * @author poussin
 * @version $Revision: 1462 $
 *
 * Last update: $Date: 2012-04-05 17:31:15 +0200 (Thu, 05 Apr 2012) $
 * by : $Author: maven-release $
 */
public class WikittyExtensionMigrationRegistry {

    /** to use log facility, just put in your code: log.info(\"...\"); */
    static private Log log = LogFactory.getLog(WikittyExtensionMigrationRegistry.class);

    protected ApplicationConfig config;

    public WikittyExtensionMigrationRegistry(ApplicationConfig config) {
        this.config = config;
    }

    public WikittyExtensionMigration get(String extensionName) {
        try {
            String key = WikittyConfigOption.WIKITTY_MIGRATION_CLASS.getKey() + extensionName;
            WikittyExtensionMigration result =
                    config.getOptionAsSingleton(WikittyExtensionMigration.class, key);
            return result;
        } catch (Exception eee) {
            throw new WikittyException("Can't get migration class in configuration", eee);
        }
    }

     public void put(String extensionName, WikittyExtensionMigration o) {
         String key = WikittyConfigOption.WIKITTY_MIGRATION_CLASS.getKey() + extensionName;
         config.putObject(key, o);
     }

}

==> wikitty-api-3.11-sources.jar: org/nuiton/wikitty/services/WikittyExtensionMigrationRegistry.java <==
/*
 * #%L
 * Wikitty :: api
 * 
 * $Id: WikittyExtensionMigrationRegistry.java 1581 2014-02-07 11:31:04Z tchemit $
 * $HeadURL: http://svn.nuiton.org/wikitty/tags/wikitty-3.11/wikitty-api/src/main/java/org/nuiton/wikitty/services/WikittyExtensionMigrationRegistry.java $
 * %%
 * Copyright (C) 2012 CodeLutin, Benjamin Poussin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */
package org.nuiton.wikitty.services;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.nuiton.config.ApplicationConfig;
import org.nuiton.wikitty.WikittyConfigOption;
import org.nuiton.wikitty.WikittyException;

/**
 * Permet de gerer les objets permettant les migrations d'extension. Il est
 * possible d'ajouter programmatiquement des objects de migration ou bien en
 * utilisant la configuration. Si les deux sont utilises l'ajout par programmation
 * est toujours preponderant sur l'utilisation du fichier de configuration.
 *
 * Pour recuperer l'objet WikittyExtensionMigrationRegistry il faut utiliser
 * <pre>
 * ApplicationConfig config = ...;
 * WikittyExtensionMigrationRegistry registry =
 *     config.getObject(WikittyExtensionMigrationRegistry.class);
 * WikittyExtensionMigration migration = registry.get(WikittyUser.EXT_WIKITTYUSER);
 * </pre>
 *
 * @author poussin
 * @version $Revision: 1581 $
 *
 * Last update: $Date: 2014-02-07 12:31:04 +0100 (Fri, 07 Feb 2014) $
 * by : $Author: tchemit $
 */
public class WikittyExtensionMigrationRegistry {

    /** to use log facility, just put in your code: log.info(\"...\"); */
    static private Log log = LogFactory.getLog(WikittyExtensionMigrationRegistry.class);

    protected ApplicationConfig config;

    public WikittyExtensionMigrationRegistry(ApplicationConfig config) {
        this.config = config;
    }

    public WikittyExtensionMigration get(String extensionName) {
        try {
            String key = WikittyConfigOption.WIKITTY_MIGRATION_CLASS.getKey() + extensionName;
            WikittyExtensionMigration result =
                    config.getOptionAsSingleton(WikittyExtensionMigration.class, key);
            return result;
        } catch (Exception eee) {
            throw new WikittyException("Can't get migration class in configuration", eee);
        }
    }

     public void put(String extensionName, WikittyExtensionMigration o) {
         String key = WikittyConfigOption.WIKITTY_MIGRATION_CLASS.getKey() + extensionName;
         config.putObject(key, o);
     }

}
